from typing import Dict, List
from structlog import BoundLogger

from zenx.exceptions import DropItem
from zenx.pipelines.base import Pipeline
from zenx.clients.database import DBClient
from zenx.settings import Settings


class PipelineManager:


    def __init__(self, pipeline_names: List[str], logger: BoundLogger, db: DBClient, settings: Settings) -> None:
        self.logger = logger
        self.pipelines = [Pipeline.get_pipeline(name)(logger, db, settings) for name in pipeline_names]
        self.settings = settings
    
    
    async def start_pipelines(self) -> None:
        """ connect and monitor """
        for pipeline in self.pipelines:
            await pipeline.start()
            

    async def process_item(self, item: Dict, spider: str) -> Dict:
        for pipeline in self.pipelines:
            try:
                item = await pipeline.process_item(item, spider)
            except DropItem:
                self.logger.warning("dropped", item=item)
                break
            except Exception:
                self.logger.exception("process_item", pipeline=pipeline.name, item=item)
                raise
        return item

    
    async def close_pipelines(self) -> None:
        for pipeline in self.pipelines:
            await pipeline.close()
